# The Galaxie microGUI

 * Introduction
 * The Galaxie event space
 * Graphics drivers
 * Font support
 * Unicode multilingual support
 * Animation support
 * Printing support
 * The Galaxie Window Manager
 * Widget library
 * Summary


## Introduction

## The Galaxie event space
    * DBus

## Graphics drivers
    * ncurses
    * graphics


## Font support
    * icons support
    * web font require

## Unicode multilingual support
    * Use the unicode

## Animation support
    * 

##  Printing support

## The Galaxie Window Manager

## Widget library
### Fundamental widgets
## Summary
